@@ -82,7 +82,7 @@ class PivotStepPerformer(StepPerformer):
         pivot_columns_column_ids: List[ColumnID] = get_param(params, 'pivot_columns_column_ids')
         values_column_ids_map: Dict[ColumnID, Collection[str]] = get_param(params, 'values_column_ids_map')
         flatten_column_headers: bool = get_param(params, 'flatten_column_headers')
-        destination_sheet_index: int = get_param(params, 'destination_sheet_index')
+        destination_sheet_index: Optional[int] = get_param(params, 'destination_sheet_index')
         use_deprecated_id_algorithm: bool = get_param(params, 'use_deprecated_id_algorithm') if get_param(params, 'use_deprecated_id_algorithm') else False
 
         pivot_rows = prev_state.column_ids.get_column_headers_by_ids(sheet_index, pivot_rows_column_ids)
@@ -150,16 +150,8 @@ class PivotStepPerformer(StepPerformer):
         ]
 
     @classmethod
-    def get_modified_dataframe_indexes( # type: ignore
-        cls, 
-        sheet_index,
-        pivot_rows_column_ids,
-        pivot_columns_column_ids,
-        values_column_ids_map,
-        destination_sheet_index=None,
-        use_deprecated_id_algorithm: bool=False,
-        **params
-    ) -> Set[int]:
+    def get_modified_dataframe_indexes(cls, params: Dict[str, Any]) -> Set[int]:
+        destination_sheet_index = get_param(params, 'destination_sheet_index')
         if destination_sheet_index: # If editing an existing sheet, that is what is changed
             return {destination_sheet_index}
         return {-1}
