@@ -3,12 +3,16 @@
 
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
+import json
 import os
 import pandas as pd
 import pytest
 
 from mitosheet.mito_widget import MitoWidget, sheet
+from mitosheet.tests.test_utils import create_mito_wrapper, create_mito_wrapper_dfs
 from mitosheet.transpiler.transpile import transpile
+from mitosheet.tests.decorators import pandas_post_1_only
+from mitosheet.utils import MAX_COLUMNS
 
 
 def test_example_creation_blank():
@@ -82,31 +86,30 @@ def test_can_call_sheet_with_df_and_filename():
 
     code_container = transpile(mito.steps_manager)
 
-    assert code_container['code'] == [
+    assert code_container == [
         '# Read in filepaths as dataframes',
         'df_1 = pd.read_csv(r\'../1.csv\')',
     ]
 
-def test_can_use_non_standard_delimeter_when_passing_string():
+def test_can_use_utf_16_when_passing_string():
     df = pd.DataFrame(data={'A': [1, 2, 3], 'B': [2, 3, 4]})
 
-    encodings = ['UTF-16', 'UTF-32']
-    for encoding in encodings:
-        df.to_csv('test_file_path.csv', index=False, encoding=encoding)
+    encoding = 'UTF-16'
+    df.to_csv('test_file_path.csv', index=False, encoding=encoding)
 
-        # Create with no dataframes
-        mito = sheet('test_file_path.csv')
-        # And then import just a test file
+    # Create with no dataframes
+    mito = sheet('test_file_path.csv')
+    # And then import just a test file
 
-        assert mito.steps_manager.dfs[0].equals(df)
+    assert mito.steps_manager.dfs[0].equals(df)
 
-        code_container = transpile(mito.steps_manager)
+    code_container = transpile(mito.steps_manager)
 
-        assert code_container['code'] == [
-            '# Read in filepaths as dataframes',
-            f'test_file_path = pd.read_csv(r\'test_file_path.csv\', encoding=\'{encoding}\')',
-        ]
-        os.remove('test_file_path.csv')
+    assert code_container == [
+        '# Read in filepaths as dataframes',
+        f'test_file_path = pd.read_csv(r\'test_file_path.csv\', encoding=\'{encoding}\')',
+    ]
+    os.remove('test_file_path.csv')
 
 
 def test_call_makes_copies():
@@ -123,4 +126,15 @@ def test_can_call_with_indexes():
     sheet(string_index)
 
     multi_index = df.set_index(['B', 'D'])
-    sheet(multi_index)
\ No newline at end of file
+    sheet(multi_index)
+
+def test_sheet_json_holds_all_columns():
+    df = pd.DataFrame({i: [1, 2, 3] for i in range(MAX_COLUMNS + 100)})
+    mito = create_mito_wrapper_dfs(df)
+    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
+    for i in range(MAX_COLUMNS, MAX_COLUMNS + 100):
+        assert sheet_data['columnIDsMap'][str(i)] is not None
+        assert sheet_data['columnSpreadsheetCodeMap'][str(i)] is not None
+        assert sheet_data['columnFiltersMap'][str(i)] is not None
+        assert sheet_data['columnIDsMap'][str(i)] is not None
+        assert sheet_data['columnDtypeMap'][str(i)] is not None
